/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2016 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.templates;

import static org.fortiss.af3.generator.common.AF3GeneratorCommonActivator.getDefault;
import static org.fortiss.tooling.kernel.utils.LoggingUtils.error;

import java.io.IOException;
import java.io.InputStreamReader;

import org.antlr.stringtemplate.StringTemplate;
import org.antlr.stringtemplate.StringTemplateGroup;
import org.antlr.stringtemplate.language.DefaultTemplateLexer;

/**
 * 
 * @author zverlov
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating RED Hash:
 */
public class RaspberryTemplateLoader {
	/**
	 * @param contextClass
	 * @param stgName
	 * @return the string template group for a given context class and template group name
	 */
	public static StringTemplateGroup loadResourceSTG(Class<?> contextClass, String stgName) {
		InputStreamReader in =
				new InputStreamReader(contextClass.getResourceAsStream(stgName +
						(stgName.contains(".") ? "" : ".stg")));
		StringTemplateGroup templates = new StringTemplateGroup(in, DefaultTemplateLexer.class);
		try {
			in.close();
		} catch(IOException e) {
			error(getDefault(), "AF3 generator could not load stringtemplate " + stgName + ".", e);
		}
		return templates;
	}

	/** Returns the Template of a Makefile for the Raspberry Platform. */
	public static StringTemplate getMakeFileTemplate(String binaryName) {
		StringTemplate template =
				loadResourceSTG(RaspberryTemplateLoader.class, "MakeFileTemplate").getInstanceOf(
						"MakeFileTemplate");
		template.setAttribute("binaryName", binaryName);
		return template;
	}

	/**
	 * @param string
	 * @return
	 */
	public static StringTemplate getMainFileTemplate(String headerFile) {
		StringTemplate template =
				loadResourceSTG(RaspberryTemplateLoader.class, "MainFileTemplate").getInstanceOf(
						"MainFileTemplate");
		template.setAttribute("headerFile", headerFile);
		return template;
	}
}
